pub enum EmergencyAccessViewError {
Api(ApiError),
MissingField(MissingFieldError),
Crypto(CryptoError),
VaultParse(VaultParseError),
}Expand description
Errors returned when viewing a grantor’s vault items through emergency access.
Variants
Api(ApiError)
The request to the server failed.
MissingField(MissingFieldError)
A required field was missing from the server response.
Crypto(CryptoError)
The grantor key is malformed or could not be decapsulated with the current user’s private key.
VaultParse(VaultParseError)
A cipher in the server response could not be parsed.